package com.bzd.web.controller.bbfx;

import org.bouncycastle.crypto.digests.SM3Digest;
import org.bouncycastle.jce.provider.BouncyCastleProvider;

import java.nio.charset.StandardCharsets;
import java.security.Security;


public class EncryptUtils {
    static {
        // 添加安全提供者（SM2，SM3，SM4等加密算法，CBC、CFB等加密模式，PKCS7Padding等填充方式，不在Java标准库中，由BouncyCastleProvider实现）
        Security.addProvider(new BouncyCastleProvider());
    }

    /**
     * SM3，国家商用密码（Shang Mi3）也称国密3，是中华人民共和国政府采用的一种密码散列函数标准，由国家密码管理局于2010年12月17日发布。
     * <p>
     * 输入：待加密的字符串
     * 输出：256位（16字节）或64个16进制字符（常用）
     * 应用：密码管理、数字签名、文件完整性校验
     * 安全性：★★☆☆☆
     *
     * @param plainString 明文
     * @return cipherString 密文
     */
    public static String sm3(String plainString) {
        String cipherString = null;
        try {
            // 创建SM3Digest对象
            SM3Digest sm3Digest = new SM3Digest();
            // 初始化SM3计算
            sm3Digest.update(plainString.getBytes(StandardCharsets.UTF_8), 0, plainString.length());
            // 创建输出缓冲区
            byte[] cipherBytes = new byte[sm3Digest.getDigestSize()];
            // 计算SM3摘要
            sm3Digest.doFinal(cipherBytes, 0);
            // 输出16进制字符串
            StringBuilder sb = new StringBuilder();
            for (byte b : cipherBytes) {
                sb.append(String.format("%02x", b));
            }
            cipherString = sb.toString();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return cipherString;
    }


}
