package com.bzd.system.service;

import com.bzd.common.config.dao.DaoBase;
import com.bzd.common.config.dao.DaoSupport;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.domain.entity.DtpDeliveryPrint;
import com.bzd.common.utils.DateUtils;
import com.bzd.common.utils.StringUtils;
import com.bzd.common.utils.uuid.IdUtils;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static com.bzd.common.utils.ShiroUtils.getSysUser;


@Service
public class DTPService {
    @Autowired
    private DaoBase dao;

    @Resource(name = "daoSupport")
    private DaoSupport daoSupport;

    /**
     * 处方列表
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public List<PageData> findForList(final PageData pd) throws Exception {
        return (List<PageData>) daoSupport.findForList("DTPMapper.RecipeRegisterList", pd);
    }

    /**
     * 处方信息
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public Object findOne(final PageData pd) throws Exception {
        return daoSupport.findForObject("DTPMapper.selectOne", pd);
    }
    @Transactional(rollbackFor = Exception.class)
    public Integer BandingRecipe(PageData pd)throws Exception {
        return daoSupport.update("DTPMapper.BangdingRecipe", pd);
    }
    /**
     * 处方登记 添加
     *
     * @param pd
     * @return
     * @throws Exception
     */
    @Transactional(rollbackFor = Exception.class)
    public PageData save(final PageData pd) throws Exception {
        pd.put("createTime", DateUtils.getTime());//处方表 处方单号时间
        Object prescriptionNumber = pd.get("prescriptionNumber");
        Object prescriptionImg = pd.get("prescriptionImg");
        Object prescriptionDate =pd.get("prescriptionDate");
        if (StringUtils.isEmpty(prescriptionNumber.toString())) {
            pd.put("prescriptionNumber", IdUtils.fastSimpleUUID());//处方表 处方单号 如果没有就自动生成
            if( StringUtils.isEmpty(prescriptionImg.toString())){
                pd.put("status",5);//待上传处方
            }
            if( StringUtils.isNotEmpty(prescriptionImg.toString())){
                pd.put("status",6);//待绑定患者6
            }
            if( StringUtils.isEmpty(prescriptionDate.toString())){
                pd.put("prescriptionDate", DateUtils.getTime());
            }

        }
        String isFlipItemStr = "否"; // 初始化 isFlipItemStr
        boolean isFlipItemFound = false; // 标志变量
        String Id = IdUtils.fastSimpleUUID();
        List<PageData> addList = new ArrayList<>();
        Object drugList = pd.get("drugList");//获取药品信息列表

        if (StringUtils.isNotNull(drugList)) {
            try {
                // 将 JSON 字符串转换为 List<Map<String, Object>>
                ObjectMapper objectMapper = new ObjectMapper();
                List<Map<String, Object>> rowsdrugList = objectMapper.readValue(drugList.toString(), List.class);
                // 遍历列表并调用插入数据接口
                if (rowsdrugList.size() > 0) {
                    for (Map<String, Object> lxr : rowsdrugList) {
                        PageData pageData = new PageData();
                        pageData.put("creator", getSysUser().getLoginName());
                        pageData.put("createTime", DateUtils.getTime());
                        pageData.put("productName", lxr.get("productName"));
                        pageData.put("genericName", lxr.get("genericName"));
                        pageData.put("prescriptionNumber", Id);//处方药品信息表d的处方单号是处方表的主键id
                        pageData.put("patientId", pd.get("patientId"));
                        pageData.put("specification", lxr.get("specification"));
                        pageData.put("usageMethod", lxr.get("usageMethod"));
                        pageData.put("quantity", lxr.get("quantity"));
                        pageData.put("frequency", lxr.get("frequency"));
                        pageData.put("wordUsage", lxr.get("wordUsage"));
                        pageData.put("medicationCycle", lxr.get("medicationCycle"));
                        pageData.put("mdmCode", lxr.get("mdmCode"));
                        pageData.put("drugCode", lxr.get("productId"));
                        pageData.put("isFlipItem", lxr.get("isFlipItem"));
                        // 检查 isFlipItem 字段的值
                        if ("是".equals(lxr.get("isFlipItem")) && !isFlipItemFound) {
                            isFlipItemStr = "是";
                            isFlipItemFound = true; // 设置标志变量
                        }
                        addList.add(pageData);
                    }
                    final HashMap<String, Object> addMap = new HashMap<String, Object>();
                    addMap.put("dataList", addList);
                    int resultDrug= dao.executeBatch("DTPMapper.batchAddPrescriptionDrug", addMap);
                }

            } catch (Exception e) {
                e.printStackTrace();
            }

        }
        pd.put("id", Id);//处方单表id主键
        pd.put("isFlipItem", isFlipItemStr);//是否包含有上翻品
        pd.put("storeId", getSysUser().getDeptId());
       int result = daoSupport.save("DTPMapper.insertRecipe", pd);
        PageData resultpageData = new PageData();
       if(result>0){
           resultpageData.put("id", Id);//处方单表id主键
           Object prescription =  daoSupport.findForObject("DTPMapper.selectOne", resultpageData);
           resultpageData.put("result", "200");
           resultpageData.put("prescription", prescription);
           return resultpageData;
       }else{
           resultpageData.put("id", Id);//处方单表id主键
           resultpageData.put("result","300");
           return resultpageData;
       }
    }


    /**
     * 处方删除
     *
     * @param ids
     * @return
     * @throws Exception
     */
    public Integer del(List<String> ids) throws Exception {
        return daoSupport.delete("DTPMapper.deleteRecipe", ids);
    }
    /**
     * 一店一目删除
     * @param ids
     */
    public Integer deleteProductList(List<String> ids) throws Exception {
        return daoSupport.delete("DTPMapper.deleteProductList", ids);
    }

    /**
     * 处方修改
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public Integer update(PageData pd) throws Exception {
        return daoSupport.delete("DTPMapper.updateRecipe", pd);
    }

    /**
     * 校验患者姓名和电话
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public boolean checkPatientNameAndPhoneUnique(PageData pd) throws Exception {

        Object obj = daoSupport.findForObject("DTPMapper.checkPatientNameAndPhoneUnique", pd);
        return StringUtils.isNull(obj);
    }

    /**
     * 校验患者姓名和身份证号
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public boolean checkPatientNameAndIdCardUnique(PageData pd) throws Exception {

        Object obj = daoSupport.findForObject("DTPMapper.checkPatientNameAndIdCardUnique", pd);
        return StringUtils.isNull(obj);
    }

    /**
     * 冷链配送列表
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public List<PageData> findColdForList(final PageData pd) throws Exception {
        return (List<PageData>) daoSupport.findForList("DTPMapper.DistributionOrderList", pd);
    }

    /**
     * 冷链配送登记 添加
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public Integer saveCold(final PageData pd) throws Exception {

        pd.put("orderNumber", "1113333");//订单编号
        LocalDateTime now = LocalDateTime.now();
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");//2024-01-01 10:00:00
        String formattedOrderTime = now.format(formatter);
        pd.put("create_time", formattedOrderTime);//订单时间
        pd.put("creationTime", formattedOrderTime);//订单创建时间
        pd.put("createdBy", "admin");//订单创建时间
        return daoSupport.save("DTPMapper.insertDistributionOrder", pd);
    }

    /**
     * 配送订单修改
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public Integer editColdOrder(PageData pd) throws Exception {
        LocalDateTime now = LocalDateTime.now();
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");//2024-01-01 10:00:00
        String formattedOrderTime = now.format(formatter);
        pd.put("updatedTime", formattedOrderTime);//订单时间
        return daoSupport.update("DTPMapper.updateDistributionOrder", pd);
    }

    /**
     * 配送订单软删除
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public Integer softDeleteColdOrder(PageData pd) throws Exception {
        return daoSupport.delete("DTPMapper.softDeleteColdOrder", pd);
    }

    /**
     * 配送单据打印列表
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public List<PageData> listPrint(final PageData pd) throws Exception {

        return (List<PageData>) daoSupport.findForList("DTPMapper.listPrintPd", pd);
    }

    /**
     * 配送单据打印导出
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public List<DtpDeliveryPrint> listPrintReport(final PageData pd) throws Exception {
        return (List<DtpDeliveryPrint>) daoSupport.findForList("DTPMapper.listPrintEntity", pd);
    }

    /**
     * 配送单据打印 添加
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public Integer savePrint(final PageData pd) throws Exception {

        LocalDateTime now = LocalDateTime.now();
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");//2024-01-01 10:00:00
        String formattedOrderTime = now.format(formatter);
        pd.put("create_time", formattedOrderTime);//订单时间
        pd.put("creationTime", formattedOrderTime);//订单创建时间
        pd.put("createdBy", "admin");//订单创建人
        pd.put("businessId", "10359");//业务ID
        pd.put("status", "待打印");//打印状态

        return daoSupport.save("DTPMapper.savePrint", pd);
    }

    /**
     * 配送单据打印修改
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public Integer editPrint(PageData pd) throws Exception {
        LocalDateTime now = LocalDateTime.now();
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");//2024-01-01 10:00:00
        String formattedOrderTime = now.format(formatter);
        pd.put("updatedTime", formattedOrderTime);//订单时间
        return daoSupport.update("DTPMapper.editPrint", pd);
    }

    /**
     * 配送单据打印软删除
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public Integer DelPrint(PageData pd) throws Exception {
        return daoSupport.delete("DTPMapper.DelPrint", pd);
    }


    /**配置信息查询模块**/
    /**
     * 一店一目标签列表
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public List<PageData> findstoreTagList(final PageData pd) throws Exception {
        return (List<PageData>) daoSupport.findForList("DTPMapper.StoreProductList", pd);
    }

    /**
     * DTP医院列表
     *
     * @param pd
     * @return
     * @throws Exception
     */
    public List<PageData> findHospitalList(final PageData pd) throws Exception {
        return (List<PageData>) daoSupport.findForList("DTPMapper.HospitalList", pd);
    }
}
